@@ -6,11 +6,18 @@ import os
 from functools import wraps
 from typing import Optional
 
+from importlib_metadata import PackageNotFoundError, version
+
 from .client.client import Client  # noqa F401
 from .excepts import AuthenticationRequiredError
 from .utils.auth import Auth  # noqa F401
 
-__version__ = '0.15.1'
+try:
+    __version__ = version("jina-hubble-sdk")
+except PackageNotFoundError:
+    __version__ = "v0.0.0"
+finally:
+    __version__ = "v0.0.0"
 
 
 def login_required(func):
@@ -83,7 +90,7 @@ def show_hint(interactive: bool = False) -> Optional[str]:  # noqa: E501
         return c.token
     except AuthenticationRequiredError:
         print(
-            ':closed_lock_with_key: [yellow bold]You are not login to Jina AI[/]. '
+            ':closed_lock_with_key: [yellow bold]You are not logged in to Jina AI[/]. '
             'To log in, use [bold]jina auth login[/] or set env variable [bold]JINA_AUTH_TOKEN[/].'
         )
         if interactive:
